@@ -44,6 +44,10 @@ if ((strlen($EDIT_PW) > 0) && ($edit == $EDIT_PW)) {
 	$EDIT = 1;
 }
 
+if (!isset($DEFAULT_WIDTH)) {
+	$DEFAULT_WIDTH = 800;
+}
+
 /* check for malicious .. in $base input */
 $PICTURE_ROOT = "pictures";
 $BASEDIR = $PICTURE_ROOT . "/" . $base;
@@ -268,6 +272,9 @@ function print_header($body=1) {
 <html>
 <head>
 <script>
+function gotourl(url) {
+	window.open(url, \"_self\");
+}
 function goto(form) {
 	var myindex = form.dest.selectedIndex;
 	window.open(form.dest.options[myindex].value, \"_self\");
@@ -301,7 +308,7 @@ body {
 	");
 	if ($body == 1) {
 		print("
-<body topmargin=0 leftmargin=0 rightmargin=0 bottommargin=0 bgcolor=#555555>
+<body topmargin=0 leftmargin=0 rightmargin=0 bottommargin=0 bgcolor=#101010>
 <table width=100% height=100%><tr><td align=center valign=center>
 		");
 	}
@@ -633,24 +640,26 @@ function build_picture_form($album, $picture, $width, $slideshow, $pictures, $de
 /****************************************************************************/
 /* Determine the link to the next picture in the flipbook */
 function get_next_link($album, $width, $pictures, $currentindex, $slideshow) {
+	global $NEXT;
 	if ($currentindex == sizeof($pictures) - 1) {
 		return "&nbsp;";
 	} else {
 		$next = $pictures[$currentindex+1];
-		$url = "?album=" . urlencode($album) . "&picture=" . urlencode($next) . "&width=$width";
+		$NEXT = "?album=" . urlencode($album) . "&picture=" . urlencode($next) . "&width=$width";
 	}
 	if ($slideshow > 0) {
-		print("<meta http-equiv='refresh' content='$slideshow;url=$url&slideshow=$slideshow'>\n");
+		print("<meta http-equiv='refresh' content='$slideshow;url=$NEXT&slideshow=$slideshow'>\n");
 	}
-	$next = "<table border=0><tr><td bgcolor=white><a href='$url'><b>Next <img src=next.png></b></a></td></tr></table>";
+	$next = "<table border=0><tr><td bgcolor=white><a href='$NEXT'><b>Next <img src=silk/resultset_next.png></b></a></td></tr></table>";
 	return $next;
 }
 
 function get_back_link($album, $width, $pictures, $currentindex) {
+	global $BACK;
 	if ($currentindex != 0) {
 		$back = $pictures[$currentindex-1];
-		$url = "?album=" . urlencode($album) . "&picture=" . urlencode($back) . "&width=$width";
-		$back = "<table border=0><tr><td bgcolor=white><a href='$url'><b><img src=prev.png> Back</b></a></td></tr></table>";
+		$BACK = "?album=" . urlencode($album) . "&picture=" . urlencode($back) . "&width=$width";
+		$back = "<table border=0><tr><td bgcolor=white><a href='$BACK'><b><img src=silk/resultset_previous.png> Back</b></a></td></tr></table>";
 		return $back;
 	} else {
 		return "&nbsp;";
@@ -779,14 +788,17 @@ function print_picture($path_to_picture, $temp, $height, $alt) {
 /****************************************************************************/
 /* Print picture img */
 function print_picture_in_table($path_to_picture, $temp, $height, $alt) {
+	global $BACK, $NEXT;
 	print("
-		<table border=0><tr><td><table border=0 cellspacing=0 cellpadding=6 align=center>
+		<table border=0 width=100%><tr><td><table border=0 width=100% cellspacing=0 cellpadding=6 align=center>
 		  <tr>
-		    <td bgcolor=black>
+		    <td width=33% onClick=javascript:gotourl('$BACK')>&nbsp;</td>
+		    <td bgcolor=black><center>
 	");
 	print_picture($path_to_picture, $temp, $height, $alt);
 	print("
-		    </td>
+		    </center></td>
+		    <td width=33% onClick=javascript:gotourl('$NEXT')>&nbsp;</td>
 		  </tr>
 		</table></td></tr></table>
 	");
@@ -814,12 +826,12 @@ function print_lower_toolbar($resizeform, $picform, $rotateform, $width) {
 /****************************************************************************/
 /* Display the flipbook page with the picture and all navigation tools */
 function do_flipbook_page($album, $picture, $width, $rotate, $slideshow) {
-	global $_SERVER, $BASEDIR;
+	global $_SERVER, $BASEDIR, $DEFAULT_WIDTH;
 	if (!$width) {
 		if ( $_SERVER["HTTP_UA_PIXELS"] ) {
 			list ($width, $trash) = preg_split("/x/", $_SERVER["HTTP_UA_PIXELS"], 2);
 		} else {
-			$width = "640";
+			$width = $DEFAULT_WIDTH;
 		}
 	}
 	$height = 3/4 * $width;
@@ -845,8 +857,8 @@ function do_flipbook_page($album, $picture, $width, $rotate, $slideshow) {
 	$next = get_next_link($album, $width, $pictures, $currentindex, $slideshow);
 	$back = get_back_link($album, $width, $pictures, $currentindex);
 
-	print_upper_toolbar($album, $descriptions[$picture], $back, $next, $width);
 	print_picture_in_table($path_to_picture, $tempfilename, $height, $alt);
+	print_upper_toolbar($album, $descriptions[$picture], $back, $next, $width);
 	print_lower_toolbar($resizeform, $picform, $rotateform, $width);
 	print_picture_details($path_to_picture, $currentindex, $total, $width, $descriptions);
 }
